aboutsummaryrefslogtreecommitdiff
path: root/clientapi/producers
diff options
context:
space:
mode:
authorKegsay <kegan@matrix.org>2020-03-30 15:02:20 +0100
committerGitHub <noreply@github.com>2020-03-30 15:02:20 +0100
commit11a8059bba9dbdc855f10e3b380c4a2f245635a2 (patch)
tree61b2ffaa53eecb6d4eef8e275f432734cbb9e606 /clientapi/producers
parentf72b759426c1895b76c16ace526cc788713c2fea (diff)
Rename the typing server to EDU server (#948)
* Blunt move and sed rename * Rename common/ refs to typing * Rename internal stuff in eduserver * Rename docs and scripts * Rename constants/filenames, goimports everything to re-order imports
Diffstat (limited to 'clientapi/producers')
-rw-r--r--clientapi/producers/eduserver.go (renamed from clientapi/producers/typingserver.go)18
1 files changed, 9 insertions, 9 deletions
diff --git a/clientapi/producers/typingserver.go b/clientapi/producers/eduserver.go
index f4d0bcba..14414ec6 100644
--- a/clientapi/producers/typingserver.go
+++ b/clientapi/producers/eduserver.go
@@ -16,24 +16,24 @@ import (
"context"
"time"
- "github.com/matrix-org/dendrite/typingserver/api"
+ "github.com/matrix-org/dendrite/eduserver/api"
"github.com/matrix-org/gomatrixserverlib"
)
-// TypingServerProducer produces events for the typing server to consume
-type TypingServerProducer struct {
- InputAPI api.TypingServerInputAPI
+// EDUServerProducer produces events for the typing server to consume
+type EDUServerProducer struct {
+ InputAPI api.EDUServerInputAPI
}
-// NewTypingServerProducer creates a new TypingServerProducer
-func NewTypingServerProducer(inputAPI api.TypingServerInputAPI) *TypingServerProducer {
- return &TypingServerProducer{
+// NewEDUServerProducer creates a new EDUServerProducer
+func NewEDUServerProducer(inputAPI api.EDUServerInputAPI) *EDUServerProducer {
+ return &EDUServerProducer{
InputAPI: inputAPI,
}
}
-// Send typing event to typing server
-func (p *TypingServerProducer) Send(
+// SendTyping sends a typing event to EDU server
+func (p *EDUServerProducer) SendTyping(
ctx context.Context, userID, roomID string,
typing bool, timeout int64,
) error {